package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````(!8``#0````TE````````#0`(``(
M`"@`'0`<``8````T````-````#0``````0````$```0````$`````P```#0!
M```T`0``-`$``!<````7````!`````$````!````````````````````4(X`
M`%".```%`````!````$```#8C@``V)X``-B>``!@`@``K`(```8`````$```
M`@```.R.``#LG@``[)X``.````#@````!@````0````$````3`$``$P!``!,
M`0``+````"P````$````!````%#E=&3LA0``[(4``.R%```T`0``-`$```0`
M```$````4N5T9-B.``#8G@``V)X``"@!```H`0``!`````$````O=7-R+VQI
M8F5X96,O;&0N96QF7W-O```'````!`````$```!.971"4T0```#RX34$````
M!`````,```!085@``````&$```!E```````````````J````"@``````````
M````,@````L````[`````````"D``````````0```$8```!=`````````!H`
M``!%````!````!D````0````%@```#T```!2````60````````!1````-P``
M`%0``````````````&$```!C````)P```%````!3````/@```&````!8````
M/P````````!"````'````"\```!7````(````"0`````````!0```$@`````
M````"````"8```!D````5@```$0````S````20```&(`````````6P``````
M```4````*````$<````````````````````.````+```````````````7```
M`"4`````````!P`````````>````-`````````!*`````P```$``````````
M-@````````````````````````!#`````````#4```!-````7@````````!?
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````/````````````````````````````````````
M`````!T````;`````````",``````````````"$````B```````````````)
M`````````!@````7````+@```!4````````````````````-`````````"T`
M```K````,0`````````````````````````````````````````\````'P``
M`````````````````!(``````````````#H````"````!@``````````````
M`````#D```!,`````````!,``````````````$\``````````````#@`````
M`````````$L`````````00````P`````````3@```!$```!5````,````%H`
M`````````````````````````````)@``````````````!(````,````````
M```````2````%```````````````$@```'\#``#>(0```P```!(`#``<````
M```````````B````*P``````````````$@```$@#`````````````!(````Q
M```````````````2````D`,``!XH```K````$@`,`#@``````````````!(`
M``!5`P`````````````2````0```````````````$@```*L#```Y,@``9P``
M`!(`#`"#```````````````2````2```````````````$@```+<#```XH0``
M`````!``%P!8```````````````2````9P``````````````$@```&T`````
M`````````!(```!T```````````````2````?@``````````````$@```(@`
M``!P10```````!``#0".```````````````2````EP``````````````$@``
M`!D"`````````````!(```"=```````````````2````JP``````````````
M$0```,0"`````````````"(```"X```````````````2````O@,``/8C```Y
M````$@`,`,L#```O)```4P```!(`#`#7`P``""D``-L&```2``P`Q@``````
M````````%@```-D``````````````!(```!G`P`````````````2````Y```
M````````````$@```.T```"`H0``!````!$`&`#U```````````````2````
M_@``````````````$@```#X#`````````````!(````*`0`````````````2
M````Y`,``.8^```V`@``$@`,`!T!`````````````!$````O`0``````````
M```2````/P$`````````````$@```$T!`````````````!(```!2`0``````
M```````1````80$`````````````$@```.\#```TH0``!````!$`%P!P`0``
M```````````2````?`$`````````````$@```(P!`````````````!(```"A
M`0`````````````2````K`$`````````````$@```'H#``"$H0```````!``
M&`#X`@`````````````2````OP$`````````````$@```"H$```@%@``````
M`!(`#`#-`0`````````````2````U0$`````````````$@```.$!````````
M`````!(```#Y`P``@B0``#D!```2``P`YP$`````````````$@```/(!````
M`````````!(````&!```'$$``/X!```2``P``P(`````````````$@```!`$
M```XH0```````!``&``<!```)R$``$X````2``P`)`0``!I#```_`@``$@`,
M``H"`````````````!(```"L`@`````````````B````*00``"`6````````
M$@`,`!$"`````````````!(````Q!```X2$``!4"```2``P`/@0``$DH``"_
M````$@`,`!@"`````````````!(```!0!```NR4``%4````2``P`(0(`````
M````````$@````<#`````````````!(````R`@`````````````@````1@(`
M````````````$@```%T"`````````````!(```!>!```$"8``#X````2``P`
M;`(`````````````$@```'4"`````````````!(```![`@`````````````2
M````,0,`````````````$@```(`"`````````````!(````D`P``0*$```0`
M```1`!@`B`(`````````````$@```%P#`````````````!(```"/`@``````
M```````2````9@0``(\^``!7````$@`,`)8"`````````````!$````9`P``
M_*````0````1`!<`:00``"`2````````$``)`&\$``#C+P``5@(``!(`#``6
M`0`````````````2````FP(`````````````$@```&X#`````````````!(`
M````;&EB<&5R;"YS;P!R96%L;&]C`&UE;6UO=F4`7U]C>&%?9FEN86QI>F4`
M<FUD:7(`<W1R8VAR`'-T<FYC;7``<W1R<F-H<@!B;V]T7T1Y;F%,;V%D97(`
M<&5R;%]C;VYS=')U8W0`86)O<G0`=6YL:6YK`%]?;'-T870U,`!P97)L7V9R
M964`7V9I;FD`7U]S=&%T-3``7V5X:70`<&5R;%]D97-T<G5C=`!03%]D;U]U
M;F1U;7``4&5R;%]S=E]S971P=@!03%]C=7)R96YT7V-O;G1E>'0`<&5R;%]A
M;&QO8P!C;&]S961I<@!E;G9I<F]N`')E861L:6YK`%]?;W!E;F1I<C,P`%!E
M<FQ?<V%F97-Y<VUA;&QO8P!?7W-T86-K7V-H:U]G=6%R9`!097)L7V=V7V9E
M=&-H<'8`7U]S<')I;G1F7V-H:P!R96%D`%!,7VUE;6]R>5]W<F%P`%!E<FQ?
M<WES7VEN:70S`%!E<FQ?9V5T7W-V`%]?7W1L<U]G971?861D<@!097)L7V-R
M;V%K7VYO8V]N=&5X=`!097)L7VYE=UA3`%!E<FQ?871F;W)K7W5N;&]C:P!0
M97)L7W-Y<U]T97)M`%]?97)R;F\`4&5R;%]M9U]S970`;6MD:7(`<&5R;%]P
M87)S90!097)L7VYE=UA37V9L86=S`&%C8V5S<P!G971P:60`;65M8VAR`'9F
M<')I;G1F`%!E<FQ?871F;W)K7VQO8VL`7TIV7U)E9VES=&5R0VQA<W-E<P!?
M7W-T86-K7V-H:U]F86EL7VQO8V%L`%!E<FQ?<W9?<V5T<'9N`'!E<FQ?<G5N
M`&QS965K`&]P96X`<W!R:6YT9@!G971U:60`<W1R;&5N`%]?<T8`<W1R8VUP
M`&QI8FTN<V\N,`!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!?7W)E9VES=&5R
M7V9R86UE7VEN9F\`;&EB8W)Y<'0N<V\N,0!L:6)P=&AR96%D+G-O+C$`<'1H
M<F5A9%]A=&9O<FL`<W1R9'5P`&QI8F,N<V\N,3(`7U]P<F]G;F%M90!?7W!S
M7W-T<FEN9W,`7U]G971P=W5I9#4P`%]?<WES8V%L;`!?7W-T<&-P>5]C:&L`
M871E>&ET`%]L:6)C7VEN:70`<W1R=&]K`%]?<F5A9&1I<C,P`%]E;F0`<&%R
M7V-U<G)E;G1?97AE8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?
M8VQE86YU<`!?961A=&$`<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]M
M:W1M<&1I<@!S:&%?=7!D871E`&UY7W!A<E]P;`!P87)?:6YI=%]E;G8`<VAA
M7V9I;F%L`%]?8G-S7W-T87)T`'AS7VEN:70`;6%I;@!?7W-T87)T`'!A<E]F
M:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L96%N`'!A<E]D
M:64`<VAA7VEN:70`6%-?26YT97)N86QS7U!!4E]"3T]4`"]U<W(O<&MG+VQI
M8B]P97)L-2\U+C0P+C`O:3,X-BUN971B<V0M=&AR96%D+6UU;'1I+T-/4D4Z
M+W5S<B]P:V<O;&EB````\)\```@```#\H```"`````"A```(````-*$```@`
M``#,GP``!@4``-"?```&#P``U)\```8;``#8GP``!AP``-R?```E(0``X)\`
M``8K``#DGP``!B\``.B?```&-@``[)\```9'``#TGP``!DX``/B?```&4```
M_)\```9>```,H```!P$``!"@```'`@``%*````<#```8H```!P8``!R@```'
M!P``(*````<(```DH```!PH``"B@```'"P``+*````<,```PH```!PX``#2@
M```'$0``.*````<2```\H```!Q,``$"@```'%```1*````<5``!(H```!Q<`
M`$R@```'&```4*````<9``!4H```!QH``%B@```''0``7*````<B``!@H```
M!R,``&2@```')```:*````<F``!LH```!R<``'"@```'*```=*````<I``!X
MH```!RP``'R@```'+0``@*````<N``"$H```!S```(B@```',@``C*````<S
M``"0H```!S0``)2@```'-0``F*````<X``"<H```!SD``*"@```'.P``I*``
M``<\``"HH```!ST``*R@```'/P``L*````=```"TH```!T(``+B@```'1@``
MO*````=)``#`H```!TP``,2@```'3P``R*````=1``#,H```!U(``-"@```'
M5```U*````=5``#8H```!U8``-R@```'5P``X*````=8``#DH```!UH``.B@
M```'6P``[*````=<``#PH```!V(``/2@```'8P``^*````=D````````````
M``````!5B>7HF`<``,G#````````_[,$````_Z,(`````````/^C#````&@`
M````Z>#_____HQ````!H"````.G0_____Z,4````:!````#IP/____^C&```
M`&@8````Z;#_____HQP```!H(````.F@_____Z,@````:"@```#ID/____^C
M)````&@P````Z8#_____HR@```!H.````.EP_____Z,L````:$````#I8/__
M__^C,````&A(````Z5#_____HS0```!H4````.E`_____Z,X````:%@```#I
M,/____^C/````&A@````Z2#_____HT````!H:````.D0_____Z-$````:'``
M``#I`/____^C2````&AX````Z?#^____HTP```!H@````.G@_O___Z-0````
M:(@```#IT/[___^C5````&B0````Z<#^____HU@```!HF````.FP_O___Z-<
M````:*````#IH/[___^C8````&BH````Z9#^____HV0```!HL````.F`_O__
M_Z-H````:+@```#I</[___^C;````&C`````Z6#^____HW````!HR````.E0
M_O___Z-T````:-````#I0/[___^C>````&C8````Z3#^____HWP```!HX```
M`.D@_O___Z.`````:.@```#I$/[___^CA````&CP````Z0#^____HX@```!H
M^````.GP_?___Z.,````:``!``#IX/W___^CD````&@(`0``Z=#]____HY0`
M``!H$`$``.G`_?___Z.8````:!@!``#IL/W___^CG````&@@`0``Z:#]____
MHZ````!H*`$``.F0_?___Z.D````:#`!``#I@/W___^CJ````&@X`0``Z7#]
M____HZP```!H0`$``.E@_?___Z.P````:$@!``#I4/W___^CM````&A0`0``
MZ4#]____H[@```!H6`$``.DP_?___Z.\````:&`!``#I(/W___^CP````&AH
M`0``Z1#]____H\0```!H<`$``.D`_?___Z/(````:'@!``#I\/S___^CS```
M`&B``0``Z>#\____H]````!HB`$``.G0_/___Z/4````:)`!``#IP/S___^C
MV````&B8`0``Z;#\____H]P```!HH`$``.F@_/___Z/@````:*@!``#ID/S_
M__^CY````&BP`0``Z8#\____H^@```!HN`$``.EP_/___Z/L````:,`!``#I
M8/S___^C\````&C(`0``Z5#\____H_0```!HT`$``.E`_/___Z/X````:-@!
M``#I,/S___^CS/___V:0_Z/8____9I#_H^S___]FD/^C^/___V:04U+HJ@$`
M`&:09I!FD&:0D%93Z"8O``"!PLF)``"-FMC^__^-@MC^__\YPW,;@\`#C9+<
M_O__*=#!Z`*-=(,$_Q.#PP0Y\W7W6U[#5U93Z.XN``"!PXV)``"+4`P#4`2+
M`(U4D`B+`H7`#X2S````OO__```QR>L:@_@'#X26````@_@#=0.+2@2#P@B+
M`H7`=!*#^`5UX0^W<@2#P@B+`H7`=>Z%R71Z9H/^_W1TP>8%C00Q.<%S:C'_
M@\[_ZQ&#^@9U!8G.*W$(@\$@.<AV$(L1@_H"=>B)SX/!(#G(=_"%_W0^@_[_
M=#F+3P@!\8L1A=)T+C'_,<#K$8/Z$G4#BWD$@\$(BQ&%TG0;@_H1=>J+000!
M\.OKBT($A<`/A&?___];7E_#C0PX.<AR$8UV`.OP@_HJ=1B#P`@YP7;D#[90
M!(/Z"'7KBQ`!\@$RZ^CH?/O__U575E.#[`3HV2T```6`B```B00DC;`4<O__
MC8`4<O__.<9S*8!^!"IU*XGR]]*-+`*#Y?@!]>L)@\8(@'\,*G44B?>+'O\3
MB0,Y[G7K@\0$6UY?7<.+'"3H'_O__U575E.#[!CHA"T``('#(X@``(ML)"R+
M="0PB?#H>?[__X7V#X07`0``C8-``0``B3"-@X`!``")P8E$)!2+1@B)`8L&
MBQ"%T@^$WP```(V+_````(D1BP`/MA"$TG01@\`!@/HO=?&)`0^V$(32=>^%
M[70(B2PDZ&/Z___H7OW__XN#\/___X7`#X3K````C8/8_O__C9/8_O__.=!S
M'8/"`XV+W/[__RG*P>H"C6R0!(G'_Q>#QP0Y[W7WC8,P=O__B00DZ!7Z__^-
M@]C^__^-D]C^__\YT',=@\(#C8O<_O__*<K!Z@*-;)`$B<?_%X/'!#GO=?>-
M@W"E__^)!"3HVOG__^A%^?__BT0D%(L`B40D"(L&B40D!(M&!(D$).@D*@``
MB00DZ$+Y__^-@_P```"-DT0!``")$.DP____QT0D$!,```"-@WRE__^)1"0,
MQT0D"`(```#'!"0$````QT0D!`````#HD?K__\<$)`$```#H]?G__^@D_O__
MZ0O___^+'"3#4U>#[`CH\O___X'#G88``("[)0$```!U2,:#)0$```&#N\S_
M__\`=`Z+@P`!``")!"3H</S__XV[Y/[__XL'A<!T!__0@\<(Z_.#N^S___\`
M=`Z-@VCH__^)!"3H5OS__X/$"%];PU-7@^P(Z(O___^!PS:&``"`NR0!````
M=5G&@R0!```!@[O8____`'08C;L$`0``B7PD!(V[:.C__XD\).@'_/__@[OX
M____`'04C;OH_O__BS^%_W0(B3PDZ/K[__^-N]C^__^+!X/X_W0'_]"#[P3K
M\H/$"%];PV:09I!FD&:055=64X/L&.@5*P``@<.TA0``A<`/A)@```"-BX`!
M``"+"8E,)!"%R0^$A`````^V"(3)=`6`^3UU1C'VBWPD$(LOA>UT,(E4)!2)
M1"0,B70D"(M$)`R)1"0$B2PDZ/[W__^%P'4'@'PU`#UT*(/'!(LOA>UUV(GH
M@\086UY?7<.)QH/&`0^V#H3)=`6`^3UU\2G&ZZ>)^BM4)!#!^@*+1"04B1"-
M;#4!B>B#Q!A;7E]=PS'MZ\!55U93@^P,Z%\J``"!P_Z$``")QXN#X/___XD$
M)(L(B4PD"#')C70D!(VK@`$``(GRB?CH$O___X7`="R+10"+5"0$C020BU`$
MB1"%TG3@@\`$BU`$B1"%TG7TB?*)^.CF_O__A<!UU(L$)(M,)`@S"'4(@\0,
M6UY?7</HNOG__U575E.![*0```#HW"D``('#>X0``(G"BZO@____BT4`B80D
MH````#'`A=)T!8`Z`'4;BX0DH````#-%``^%*@$``('$I````%M>7UW#B10D
MB50D&.CQ]___B40D$(7`=-&-@Y&E__^)1"04C8.0I?__B40D'(M$)!")!"3H
M^?G__X7`#X2S````C5`-N0(```")UHM\)!3SI@^7P!P`A,!TT[D#````B=:+
M?"0<\Z8/E\`<`(3`=+V)5"0@BWPD&(D\).B"^?__B<:+5"0@B10DZ'3Y__^-
M1`8"B00DZ'CY__^)QHM4)"")5"0,B7PD"(V#DZ7__XE$)`2)-"3H&/G__XU$
M)"2)1"0$B30DZ*CV__^#^/]T$(M$)"PE`/```#T`0```=#J)-"3H6_;__XDT
M).@C]O__Z3G___^+5"08B50D%(M$)!")!"3HVO;__XM4)!2)%"3HGO7__^G1
M_O__B?#HF/[__V:0Z\/H2?C__U575E.#["CH;B@``('##8,``(G%B=:+@^#_
M__^)1"04BSB)?"0D,?^`.CUU`X/&`8DT).BA^/__B40D#(U4)"")Z.@2_?__
MB<>%P`^$XP```(D$).B`^/__.T0D#`^#O@```(M$)""-#(4`````C8.``0``
MB40D$`^V10"$P`^$:@$``#P]#X1B`0``B>CK!8#Z/70*@\`!#[80A-)U\2GH
MBU0D$(LZ`<^+3"0,C40(`HD$).@P^/__B0>%P`^$/@$``(M4)!"+`HM4)""+
M%)"-30$/MD4`B`*$P'42ZQ2#P@&#P0$/MD'_B`*$P'0$/#UU[,8"/3'`#[8,
M!HA,`@&#P`&$R77Q,<"+?"04BW0D)#,W#X7R````@\0H6UY?7<.#Q@&#QP$/
MMD;_B$?_A,!U[^O3C8.``0``B40D$(L0BSJ%_P^$JP```#'`ZP*)^(UX`8L,
MNH7)=?2-!(4,````BXM(`0``A<EU8(E4)!C'@T@!```!````B00DZ&CW__^%
MP'1\C0R]`````(E,)`B)3"0<BU0D&(E4)`2)1"08B00DZ-'S__^+3"00BT0D
M&(D!BTPD'(M$)!C'1+@$`````(E\)"#IK?[__XE$)`2)%"3HDO/__XE$)!B+
M3"00B0&%P'0<C0R]`````.O(,<#IK/[__[@(````,?_I8/___[C_____Z?[^
M___H.?;__U=64X'LB````.A<)@``@</[@```B<>+L^#___^+!HF$)(0````Q
MP(U$)`B)1"0$B3PDZ.+S__^%P'5)BU0D$('B`/```('Z`$```'0=@?H`H```
M=!6+C"2$````,PYU*('$B````%M>7\/'1"0$`@```(D\).AO]?__A<`/E,`/
MML#KT3'`Z\WHK/7__U6)Y5=64X/D\('L,`0``.C))0``@<-H@```B40D)(E4
M)""+@^#___^)1"0HBPB)C"0L!```,<G'1"0(_P,``(UT)"R)="0$C8.9I?__
MB00DZ-?S__^)1"0<A<`/CHD```"->/]EH0`````K@]S___^+$(!\/"P`=%.+
M?"0<B50D'(E\)`C'1"0$+P```(DT).CG]/__A<"+5"0<=#.)?"0,B70D"(M$
M)"2)1"0$B10DZ`?U__^+1"0HBXPD+`0``#,(=3:-9?1;7E]=PX7_=:V+1"0@
MB40D"(M$)"2)1"0$B10DZ`3S___KRV6A`````"N#W/___XL0Z];HK?3__U=6
M4X'L$`0``.C0)```@<-O?P``B[O@____BQ>)E"0,!```,=+'1"0(``0``(E$
M)`2-="0,B30DZ,#Q__^#Z`$Y\'<,ZP_&``"#Z`$Y\'0%@#@O=/''1"0$+P``
M`(DT).C8\?__A<!T)CGP=QV)-"3H*/3__XN,)`P$```S#W4?@<00!```6UY?
MP\8``.O>C8.1I?__B00DZ`#T___KUN@)]/__58GE4X/D\(/L$.@K)```@</*
M?@``C8/@Y?__B40D#(N#T/___XE$)`B-@ZNE__^)1"0$9:$`````*X/<____
MBP")!"3H\/+__XM=_,G#58GE5E.#Y/"#["#HW",``('#>WX``&6A`````"N#
MW/___XG&BP")!"3HA/___\=$)!0`````C8./I?__B40D$(E$)`R-@^./__^)
M1"0(C8/'I?__B40D!(L&B00DZ/GR__^-9?A;7EW#,<##55=64X'LL`0``.AQ
M(P``@<,0?@``BZPDQ`0``(NT),@$``"+@^#___^)1"0HBQ")E"2L!```,=*-
M5"0LC8/<I?__Z!CX__^)Q\=$)`0O````B2PDZ%;P__^%P'0MB>J-@^6E___H
MG/K__XGHBTPD*(N4)*P$```S$0^%D0$``('$L`0``%M>7UW#B30DZ*WR__^-
MB_*E__^)3"0@B4PD!(D$).@'\?__B<:%P'2OC8.1I?__B40D)(EL)!R)_8`^
M``^$\P```(7M=!2)="0$B2PDZ"CS__^%P`^$M````(DT).CX\O__B<>-1`;_
M.<9S)(`X+W0+ZQV`."^-="8`=0K&``"#Z`$YQG7MB30DZ,SR__^)QXM$)!R)
M!"3HOO+__XU$!P$]_P,```^'@0```(M$)!R)1"08C8/9IO__B40D%(ET)!"-
M@_RF__^)1"0,QT0D"``$``#'1"0$`````(VT)*P```")-"3HL/#__XU$)#")
M1"0$B30DZ-#O__^%P'40BT0D."4`\```/0"```!T3XM$)"")1"0$QP0D````
M`.@(\/__B<:%P`^%#?___XML)!SIH_[__X7M=!:Y`@```(GNBWPD)/.F#Y?`
M'`"$P'2_OP$```"+="0DZ3/____'1"0$`0```(DT).@-\?__A<!UG8GRC8/E
MI?__Z`/Y__^)-"3H-/'__^E<_O__Z#KQ__]64X/L".AA(0``@<,`?```BW0D
M%,=$)`0O````B30DZ*;N__^%P'0#C7`!B30DZ/?P__^#Q`A;7L-64X/L!.@H
M(0``@</'>P``BW0D$(7V=".`/@!T'HDT).AL\?__@\`!/0`$``!W((GP@\0$
M6U[I&?S__XV#D:7__XD$).BH\/__@\0$6U[#,<#K]E=64X/L".C4(```@<-S
M>P``B[O@____BP>)1"0$,<"-@_2E___H2O;__XV#_:7__^@_]O__C8,%IO__
MZ#3V__^-@PZF___H*?;__XV#%:;__^@>]O__C8,EIO__Z!/V__^-@]RE___H
M"/;__XV#,:;__^C]]?__C8,[IO__Z/+U__^-@T6F___HY_7__XV#Y:7__^C<
M]?__B>:)\HV#3Z;__^@7]?__A<!T#8G"C8,[IO__Z*WW__^)\HV#8*;__^CY
M]/__A<!T#8G"C8-RIO__Z(_W__^)\HV#?:;__^C;]/__A<!T+8G"C8/<I?__
MZ''W__^-DYZF__^-@Q6F___H8/?__XM$)`0S!W4G@\0(6UY?PXGRC8.-IO__
MZ)WT__^%P'3/B<*-@S&F___H,_?__^O`Z'7O__]64X/L".B<'P``@<,[>@``
MB[/@____BP:)1"0$,<")XHV#,:;__^A:]/__A<!T$0^V`(3`=`H\,`^5P`^V
MP.L",<"+3"0$,PYU!H/$"%M>P^@@[___4X/L#.A('P``@</G>0``C40D&(E$
M)`B+1"04B40D!(N#_/___P6P````B00DZ,[N___'!"3_````Z/+K__]5B>57
M5E.![#0``0#H`A\``('#H7D``(E$)"2+N^#___^)?"00BS>)M"0P``$`,?;'
M1"0,`@```,=$)`0`````QT0D"`````")!"3HPN[__X/`_X/2_XG&B=<E__\`
M`(E$)!R)T"4```"`B40D((7`>2.#1"0<_XM$)!P-``#__[G_____B<J#P`&#
MT@")1"0<B50D("MT)!P;?"0@A?\/B/,```"-3"0HC8.@IO__B40D&(V#K:;_
M_XE$)!2)3"0<QT0D#`````")="0$B7PD"(M$)"2)!"3H->[__R'0@_C_BTPD
M'`^$R@```,=$)`@(``$`B4PD!(E,)!R+1"0DB00DZ+KL__^#^/^+3"0<#X2/
M````@_@'=F*-1`'X.<AR6HT5*`$``(ET)!R)?"0@ZP>#Z`$YR'([BSP:.3AU
M\HNS+`$``#EP!'7GBW0D'(M\)"`IR)D!\!'ZBWPD$(NT)#```0`S-W5B@<0T
M``$`6UY?7<.+="0<BWPD(('&``#__X/7_XGZ]]*)\#4``/__"<(/A27___^X
M_____[K_____Z[:+1"04B00DZ!+^__^+3"0<Z\:+1"08B00DZ`#^__^+3"0<
MZ2'____H$NW__U.#[`3H.AT``('#V7<``.AN[?__B00DZ$;M__^%P'0'BP"#
MQ`1;PS'`Z_=55U93@^P@Z`P=``"!PZMW``"+?"0TB[/@____BP:)1"0<,<"-
M5"08C8.YIO__Z,3Q__^%P'0'B<6`.`!U'8GZC8.YIO__Z%/T__^+1"0<,P9U
M9X/$(%M>7UW#B3PDZ!3M__^)1"04B2PDZ`CM__^+5"04C40"`HD$).@([?__
MB<*);"00C8/RI?__B40D#(E\)`B-@_RF__^)1"0$B10DB50D%.B>[/__BU0D
M%(V#N:;__^CF\___ZY'H*.S__U575E.![!P!``#H2AP``('#Z78``(N$)#`!
M``")1"0LBX/@____B40D,(L(B8PD&`$``#')C8/5IO__B40D/(V#D:7__XE$
M)$#'1"1$`````(V#<J;__XE$)"")1"14C8-KIO__B40D6(V#VZ;__XE$)%R-
M@XBF__^)1"1@C8/CIO__B40D9,=$)&@`````C;O)IO__B7PD2(V#YZ;__XE$
M)$S'1"10`````(U4)#B)5"0DC8/<I?__Z'KP__^%P'0)@#@`#X4%`@``Z$;^
M__^)Q87`#X0P`@``B2PDZ-;K__^-1``!B00DZ-KK__^)1"0<@'T``'0JBW0D
M'(V[\*;__P^V10")1"0(B7PD!(DT).ARZ___@\4!@\8"@'T``'7@C7PD5(M$
M)""+;"0DZPV#QP2+!X7`#X1<`0``B>KH].___XG&A<!TYH`X`'3AZ)OT__^%
MP&:0=-:)-"3HMNK__XG&A<`/A"T!``")\(L(@\`$C9'__O[^]]$ARH'B@("`
M@'3I]\*`@```#X3,`0``B=$`T8/8`RGPBWPD'(GYBSF#P02-E__^_O[WUR'Z
M@>*`@("`=.F)S_?"@(```'4&P>H0@\<"B=$`T8/?`XML)!PI[XV\.`0$``")
M/"3HY>K__XG!B40D'(EL)!2-@_6F__^)1"00C8/9IO__B40D((E$)`R)="0(
MC8/ZIO__B40D!(G.B0PDZ&OJ___'1"0$P`$``(DT).A[Z?__@_C_#X0R`0``
MC40D;(E$)`2+1"0<B00DZ+[G__^)1"0TA<!U%(M$)'0E`/```#T`0```#X13
M`0``BT0D'(E$)`R+1"0LBP")1"0(C8.LI___B40D!(N#_/___P6P````B00D
MZ+/G__\Q[>M1,?^+=+P\A?9T)H`^`'0AB?#H0//__X/'`87`=.6)-"3H6NG_
M_X7`=-F)QNFC_O__,?;IG/[__XD$)(E$)!SH9?S__XM$)!R)!"3H,.G__XG%
MB>B+3"0PBY0D&`$``#,1#X77`P``@<0<`0``6UY?7<.)^#'_A<!T'8M4)"3H
M'>[__X/'`87`=`6`.`!U(XM$O$B%P'7CQP0D#0```.B-Z?__B40D'(VKSJ;_
M_^FN_?__B00DZ,;H__^%P'31B<7I??W__\'J$(/``NDI_O__Z!OH__^#.!$/
MA,#^__]FD.@+Z/__BP")1"00BT0D'(E$)`R+1"0LBP")1"0(C8-PI___B40D
M!(N#_/___P6P````B00DZ);F__\Q[>DQ____B[0DA````.C3Z/__.<8/A9G^
M__^+1"1T)?\!```]P`$```^%A?[__XD\).C?Z/__B<6+5"0DC8/$IO__Z#[M
M__^%P`^$7`$``(E$)`2+1"0LBP")!"3HQ?3__XE$)"2%P`^$/@$``(M\)"2)
M/"3HC.C__X/X`W8WB7PD)(UT!_RY!0```(V[`Z?___.F#Y?"@-H`A-)U&(/X
M!`^$+@(``(M\)"2`?`?[+P^$'P(``.A&^/__A<!U'L=$)`0`````BT0D)(D$
M).CCY___B<:%P`^%W@```(V3GJ;__XV#,:;__^@_[___Z$/G__^-LX^E__^)
M="04B40D$(M$)"")1"0,BT0D'(E$)`B-@R>G__^)1"0$B2PDZ+/G__^-NS6G
M__^)="0DBW0D-.L^Z)[F__^#.!%U28/&`>CQYO__BTPD)(E,)!B)="04B40D
M$(M$)"")1"0,BT0D'(E$)`B)?"0$B2PDZ&7G___'1"0$P`$``(DL).AUYO__
M@_C_=*V+1"0<B00DZ(3D__^)ZHV#W*7__^B.[O__B2PDZ.CY___IC/W__XM$
M)"R+`(E$)"3IL_[__^C4]___B40D)(E4)"B%T@^(#?___\=$)`P`````@\#V
M@]+_B40D!(E4)`B)-"3HN.;__\=$)`@&````C80DZ0```(E$)`2)-"3H3>7_
M_X/X!G0.C8,-I___B00DZ#KW__^+@]CE__\YA"3I````#X6N_O__#[>#W.7_
M_V8YA"3M````#X69_O__QT0D#`````"+1"0DBU0D*(/`SH/2_XE$)`2)5"0(
MB30DZ#SF___'1"0(*````(V\).\```")?"0$B30DZ-'D__^#^"AT#HV##:?_
M_XD$).B^]O__QH0D%P$```"-@X^E__^)1"04B7PD$(M$)"")1"0,BT0D'(E$
M)`B-@QBG__^)1"0$B2PDZ`;F___IL?[__XM$)"R+4`2%T@^$TOW__XD4)(E4
M)"SH%N;__X/X`P^&O?W__XM4)"R-=`+\N04```"-NPBG___SI@^7P!P`A,`/
MA9O]__^)5"0DZ9+]___H3>7__U6)Y5=64X/D\(/L(.AM%0``@<,,<```B[O@
M____BP>)1"0<,<!EH0`````K@]S___^+``^V4&2(4&6-1"08B40D%(G"C8,5
MIO__Z`[J__^%P'0)@#@Q#X24`0``D.@]]/__QT0D#`,```#'1"0(`0```(V#
M1J?__XE$)`1EH0`````K@]S___^)QHL`B00DZ'GC__^%P'0TC9-(I___B50D
M"(M0#(E$)!"+$HE4)`2+%HD4).C4XO__BT0D$(M`#(L`]D`*0`^%2@$``,=$
M)`P#````QT0D"`$```"-@TVG__^)1"0$9:$`````*X/<____B<:+`(D$).@/
MX___A<")1"00=#*+5"04C8/EI?__Z$CI__^%P(M,)!`/A-X```")1"0(BT$,
MBP")1"0$BP:)!"3H5>+__\=$)`@!````C8-/I___B40D!&6A`````"N#W/__
M_XG&BP")!"3HZ^+__XV39*?__XE4)`B)1"0$BP:)!"3H$^+__XL&QD!E`(M4
M)!2-@]RE___HSNC__XF#3`$``(7`=#''1"0$P`$``(D$).@DX___@_@1=`B-
M4`&#^@%W<XM$)!PS!P^%CP```(UE]%M>7UW#BX-0`0``B00DZ$WW__^)@TP!
M``"%P'6WC8,`J/__B00DZ'WB__^`>`$`#X1H_O__Z5W^__^+00R+DU`!``"+
M$HL`Z)#M___I(O___XE$)`2+!HD$).B9XO__Z:/^__^)1"0,BX-,`0``B40D
M"(N#4`$``(L`B40D!(V#)*C__XD$).@<XO__Z/?B__]55U93@^P$Z!P3``"!
MP[MM``"+;"08Z&?S__^%P'0*A>UT!H!]``!U"(/$!%M>7UW#B2PDZ+WQ__^)
M!"3H?/'__[D$````C;OUIO__B<;SI@^7P!P`A,!UT(GH@\0$6UY?7>G6Z/__
M55=64X'L9`$``.BV$@``@<91;0``B70D'(D$)(NVX/___XET)!B+/HF\)&`!
M```Q_XU8'#'`C50D((L,@P_)B0R"@\`!@_@0=?"-C"0@`0``BT(T,T(@,T((
M,P+1P(E"0(/"!#G*=>F+/"2+-XM?!(MO"(M/#(M'$(G"BT0D((E4)!2-E`*9
M>8):B?#!P`4!T(GJ,<HAVHE,)`0QR@'"B5PD#(G9P<D"B>@QR(GW(?`QZ(M<
M)"2+="0$C;0>F7F"6@'&B=#!P`4!QHE\)`B)^,'(`HG'B<@Q^"'0,<B+7"0H
MB6PD$(V<'9EY@EH!PXGPP<`%`</!R@*)^#'0(?`Q^(ML)"R-C"F9>8):`<B)
MW<'%!0'HP<X"B=4Q]8GI(=DQT8ML)#"-O"^9>8):`?F)Q<'%!0'IP<L"B?4Q
MW8GO(<<Q]XML)#2-E"J9>8):`?J)S<'%!0'JP<@"B<>)V#'X(<@QV(ML)#B-
MM"Z9>8):`?")UL'&!0'PB<[!S@*)_3'UB>DAT3'YBVPD/(V<*YEY@EH!V8G#
MP<,%`=F)T\'+`HGR,=HAPC'RBVPD0(V\+YEY@EH!^HG-P<4%`>K!R`*)QXG8
M,?@AR#'8BVPD1(VT+IEY@EH!\(G6P<8%`?")SL'.`HG],?6)Z2'1,?F+;"1(
MC9PKF7F"6@'9B</!PP4!V8G3P<L"B?(QVB'",?*+;"1,C;POF7F"6@'ZB<W!
MQ04!ZL'(`HG'B=@Q^"'(,=B+;"10C;0NF7F"6@'PB=;!Q@4!\(G.P<X"B?TQ
M]8GI(=$Q^8ML)%2-G"N9>8):`=F)P\'#!0'9B=/!RP*)\C':(<(Q\HML)%B-
MO"^9>8):`?J)S<'%!0'JP<@"B<6)V#'H(<@QV(M\)%R-M#Z9>8):`?")UL'&
M!0'PP<D"B>XQSB'6,>Z+?"1@C;P[F7F"6@'^B</!PP6)WP'WP<H"B<LQTR'#
M,<N+="1DC;0UF7F"6@'SB?[!Q@4!WL'(`HG3,<,A^S'3BVPD:(V,*9EY@EH!
MRXGUP<4%`>O!SP*)Q3']B>DA\3'!BVPD;(V4*IEY@EH!T8G:P<(%`='!S@*+
M5"1PC800H>O9;HGZ,?(QV@'"B<C!P`4!PL'+`HM$)'2-O`>AZ]ENB?`QV#'(
M`?B)U<'%!0'HB<W!S0*)[XM,)'B-M`ZAZ]ENB=TQ_8GI,=$!\8G&P<8%`?&)
MUL'.`HM4)'R-G!.AZ]ENB?HQ\C'"`=J)R\'#!0':P<@"B<.+A"2`````C;P'
MH>O9;HGP,=@QR`'XB=7!Q04!Z(G-P<T"B>^+C"2$````C;0.H>O9;HG=,?V)
MZ3'1`?&)QL'&!0'QB=;!S@*+E"2(````C9P3H>O9;HGZ,?(QP@':B<O!PP4!
MVL'(`HG#BX0DC````(V\!Z'KV6Z)\#'8,<@!^(G5P<4%`>B)S<'-`HGOBXPD
MD````(VT#J'KV6Z)W3']B>DQT0'QB<;!Q@4!\8G6P<X"BY0DE````(V<$Z'K
MV6Z)^C'R,<(!VHG+P<,%`=K!R`*)PXN$))@```"-O`>AZ]ENB?`QV#'(`?B)
MU<'%!0'HB<W!S0*)[XN,))P```"-M`ZAZ]ENB=TQ_8GI,=$!\8G&P<8%`?&)
MUL'.`HN4)*````"-G!.AZ]ENB?HQ\C'"`=J)R\'#!0':P<@"B<.+A"2D````
MC;P'H>O9;HGP,=@QR`'XB=7!Q04!Z(G-P<T"B>^+C"2H````C;0.H>O9;HG=
M,?V)Z3'1`?&)QL'&!0'QB=;!S@*+E"2L````C9P3H>O9;HGZ,?(QP@':B<O!
MPP4!VL'(`HG#BX0DL````(V\!Z'KV6Z)\#'8,<@!^(G5P<4%`>B)S<'-`HGO
MBXPDM````(VT#J'KV6Z)W3']B>DQT0'QB<;!Q@4!\8G6P<X"BY0DN````(V<
M$Z'KV6Z)^C'R,<(!VHG+P<,%`=K!R`*)Q8N$)+P```"-G`>AZ]ENB?`QZ#'(
M`=B)T\'#!0'8P<D"B>L)RR'3B=^)ZR'+"?N+O"3`````C;0^W+P;CP'SB<;!
MQ@4!\\'*`HG."=8AQHGWB<XAU@G^B[PDQ````(V\/=R\&X\!_HG=P<4%B>\!
M]\'(`HG6"<8AWHGUB=8AQ@GNBZPDR````(V,*=R\&X\!SHG]P<4%`>[!RP*)
MW8G#">LA^XG!(>D)V8N<),P```"-G!K<O!N/`=F)\\'#!0'+P<\"B>H)^B'R
MB=&)ZB'Z"<J+C"30````C8P(W+P;CP'*B=C!P`6)P0'1P<X"B?@)\"'8B<*)
M^"'P"="+E"34````C905W+P;CP'0B<K!P@4!PL'+`HGP"=@AR(G%B?`AV`GH
MBZPDV````(V\+]R\&X\!^(G5P<4%`>B)S<'-`HGOB=T)_2'5B=DA^0GIBZPD
MW````(VT+MR\&X\!\8G&P<8%`?&)UL'.`HGZ"?(APHG5B?HA\@GJBZPDX```
M`(V<*]R\&X\!VHG+P<,%`=K!R`*)PXGP"=@AR(G%B?`AV`GHBZPDY````(V\
M+]R\&X\!^(G5P<4%`>B)S<'-`HGOB=T)_2'5B=DA^0GIBZPDZ````(VT+MR\
M&X\!\8G&P<8%`?&)UL'.`HGZ"?(APHG5B?HA\@GJBZPD[````(V<*]R\&X\!
MVHG+P<,%`=K!R`*)PXGP"=@AR(G%B?`AV`GHBZPD\````(V\+]R\&X\!^(G5
MP<4%`>B)S<'-`HGOB=T)_2'5B=DA^0GIBZPD]````(VT+MR\&X\!\8G&P<8%
M`?&)UL'.`HGZ"?(APHG5B?HA\@GJBZPD^````(V<*]R\&X\!VHG+P<,%`=K!
MR`*)Q8GP">@AR(G#B?`AZ`G8BYPD_````(V<']R\&X\!V(G3P<,%`=C!R0*)
MZPG+(=.)WXGK(<L)^XN\)``!``"-M#[<O!N/`?.)QL'&!0'SP<H"B<X)UB'&
MB?>)SB'6"?Z+O"0$`0``C;P]W+P;CP'^B=W!Q04![L'(`HG5"<4AW8G7(<<)
M[XNL)`@!``"-C"G<O!N/`?F)]<'%!0'IP<L"B<4)W2'UB<<AWPGOBZPD#`$`
M`(V4*MR\&X\!UXG*P<(%`=?!S@*+E"00`0``C900UL%BRHG8,?`QR`'0B?K!
MP@4!T,')`HN4)!0!``"-G!/6P6+*B?(QRC'Z`=J)P\'#!0':P<\"BYPD&`$`
M`(VT'M;!8LJ)RS'[,<,!\XG6P<8%`?.)QL'.`HN$)!P!``"-C`'6P6+*B?@Q
M\#'0`<B)W<'%!0'HP<H"B=&+E"0@`0``C907UL%BRHGU,<V)[S'?`=>)PL'"
M!0'7P<L"BY0D)`$``(VT%M;!8LJ)RC':,<(!\HG^P<8%`?*)QL'.`HN$)"@!
M``"-A`'6P6+*B=TQ]8GI,?D!P8G0P<`%`<'!SP*+A"0L`0``C9P#UL%BRHGP
M,?@QT`'8B<O!PP4!V(G3P<L"BY0D,`$``(V4%M;!8LJ)_C'>,<X!UHG"P<(%
M`=;!R0*+E"0T`0``C;P7UL%BRHG:,<HQP@'ZB?7!Q04!ZL'(`HG'BX0D.`$`
M`(V$`];!8LJ)RS'[,?,!PXG0P<`%`</!S@*+A"0\`0``C8P!UL%BRHGX,?`Q
MT`'(B=W!Q04!Z,'*`HG1BY0D0`$``(V4%];!8LJ)]3'-B>\QWP'7B<+!P@4!
MU\'+`HN4)$0!``"-M!;6P6+*B<HQVC'"`?*)_L'&!0'RB<;!S@*+A"1(`0``
MC80!UL%BRHG=,?6)Z3'Y`<&)T,'`!0'!P<\"BX0D3`$``(V<`];!8LJ)\#'X
M,=`!V(G+P<,%`=B)T\'+`HN4)%`!``"-E!;6P6+*B?XQWC'.`=:)PL'"!0'6
MP<D"BY0D5`$``(V\%];!8LJ)VC'*,<(!^HGUP<4%`>K!R`*+O"18`0``C;P[
MUL%BRHG+,<,Q\P'[B=7!Q04!Z\'.`HN\)%P!``"+;"0(C;P]UL%BR@'/B<4Q
M]8GI,=$!^8G?P<<%`?F+/"2)#P-<)`R)7P3!R@(#5"00B5<(`W0D!(EW#`-$
M)!2)1Q"+1"08B[PD8`$``#,X=0N!Q&0!``!;7E]=PXM<)!SHH=;__U.#[`3H
MR08``('#:&$``,<$)&````#H)M?__\<``2-%9\=`!(FKS>_'0`C^W+J8QT`,
M=E0R$,=`$/#ATL/'0!0`````QT`8`````,=`7`````"#Q`1;PU575E.#[`B+
M7"0@BU0D)(T$U0````"+3"0<`T$4#Y+!#[;)B<Z+3"0<BTD8A?9T`X/!`8M\
M)!R)1Q2)T,'H'0'(B4<8BT]<C6\<A<ET8;Y`````*<Z)T#GR#X\U`0``B00D
MC7P-`(G>@_@$#X-6`0``]@0D`@^%"P$``/8$)`$/A?L```"+="0<BTY<`<&)
M3ER#^4!T"(/$"%M>7UW#*<*)%"0!PXGPZ`[S__^+%"2#^C\/CI0```"-0L")
M!"2)Q\'O!HUW`<'F!@'>B7PD!(M\)!R+`XE%`(M#!(E%!(M#"(E%"(M##(E%
M#(M#$(E%$(M#%(E%%(M#&(E%&(M#'(E%'(M#((E%((M#)(E%)(M#*(E%*(M#
M+(E%+(M#,(E%,(M#-(E%-(M#.(E%.(M#/(E%/(/#0(GXZ'[R__\Y\W63BWPD
M!,'G!HL4)"GZB=")[XG>@_H$<U.H`G4=J`%U#XM$)!R)4%R#Q`A;7E]=PZ2+
M1"0<B5!<Z^YFI:@!=.'K[J3I__[__V:E]@0D`0^$\_[__^OLB?")!"2-?`T`
MB=Z#^`0/@LG^___K'??%`0```'5>]\<"````=6N)P<'I`O.EJ`)TENNQ]\<!
M````=2[WQP(```!U%(L,),'I`O.E]@0D`@^$DO[__^N;#[<.9HD/@\<"@\8"
M@RPD`NO:#[8+B`^#QP&-<P&-2/^)#"3KOP^V`XM,)!R(01R#QP&#Q@&-0O_K
MC0^W#F:)#X/'`H/&`H/H`NN$55=64X/L$.@Q!```!=A>``")1"0$BW0D)(M<
M)"B+4Q2+0QB)1"0(B='!Z0.#X3^-:QR-00'&1`T`@(U\!0"#^#@/CBX!``"Y
M0````"G!=`TQP,8$!P"#P`$YR'+UB50D#(G8Z!SQ__^)[[TX````,<#WQP$`
M``"+5"0,#X5R`0``]\<"````#X5<`0``B>G!Z0+SJ_?%`@```'0"9JN#Y0$/
MA>P```"+?"0(B?C!Z!B(0U2)^,'H$(A#58GXB&-6B$-7B=#!Z!B(0UB)T,'H
M$(A#68AS6HA36XG8Z*3P__^+`\'H&(@&BP/!Z!"(1@&+`XAF`HL#B$8##[9#
M!XA&!`^W0P:(1@6+0P2(9@:+0P2(1@</MD,+B$8(#[=#"HA&"8M#"(AF"HM#
M"(A&"P^V0P^(1@P/MT,.B$8-BT,,B&8.BT,,B$8/#[9#$XA&$`^W0Q*(1A&+
M0Q"(9A*+0Q"(1A.)'"2+7"0$Z$?0__^#Q!!;7E]=P[DX````*<$Q[8/Y!',6
M]L$"=4&#X0$/A!;___^)Z*KI#O____?'`0```'4W]\<"````=3>#^01RU8G(
M@^#\B40D##'`B2P'@\`$.T0D#'+T`<?KNHGH9JN#X0$/A-'^___KN8GHJH/I
M`>O!B>AFJX/I`NO`9JN#[0+IFO[__ZJ]-P```.F#_O__58GE5U93@^3P@^Q`
MZ#8"``"!P]5<``"+10R)1"0TBT40B40D,(N#X/___XE$)"R+,(ET)#PQ]HU$
M)#")1"0(C40D-(E$)`2-10B)!"3HM-#__XN#Z/___XE$)`B)1"0$BX/T____
MB00DZ.C0__^+@]3___^`.``/A!8!``!EH0`````K@]S___^+`("(6@(```.+
M10B->`.#P`0]____/P^'4P$``,'@`HD$).@5T/__B8-0`0``BW0D-(L6B1"-
MDVJG__^)4`2-DS0!``"+$HE0"(V3;:?__XE0#(M-"(/Y`0^.!P$``+H!````
MB7PD*(L\EHE\D`R#P@$YT77RBWPD*(T4C0P```#'!!``````QT0D$`````")
M1"0,B7PD"(V#=8'__XE$)`2+@U0!``")!"3H;=#__X7`#X2;````BX-4`0``
MB00DZ/?.__^)QHU\)#B)^HV#):;__^C$U?__A<!T8HN#5`$``(D$).B2SO__
MZ.W/__^)\(MT)"R+3"0\,PX/A:,```"-9?1;7E]=P^C.SO__B8-4`0``A<`/
MA(T```")!"3H&,[__V6A`````"N#W/___XL`QH#Z!````.FU_O__BX-,`0``
MA<!T/XD$).A%[?__ZXJ+@U0!``")!"3H3-#__^E2____NA````#I$?___XN#
MY/___XE$)`2-@Y:E__^)!"3H)<___XGZC8/<I?__Z`C5__^)@TP!``"%P`^$
M.O___^NDZ.//___'!"0!````Z.?,__^+!"3#BQ0DPXL<),.+-"3#````````
M`%6)Y>CAT___R<,``'!S7W-T<FEN9W,@;6ES<VEN9PH`+BX`)7,O)7,`+W!R
M;V,O8W5R<')O8R]E>&4`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN
M=&5R;F%L<SHZ4$%2.CI"3T]4`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`%!%
M4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%
M1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!0
M05)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`
M4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`,0!L<V5E:R!F86EL
M960`<F5A9"!F86EL960`3$1?3$E"4D%265]0051(`%5315(`4UE35$5-`"]T
M;7`O`%1%35!$25(`5$U0`%5315).04U%`"4P,G@`<&%R+0`E<R5S)7,E<P!P
M87)L`"YP87(`<VAO<G0@<F5A9``E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE
M=25S`"5S)7-T96UP+25U+25U)7,`&`!P97)L`#``4$%2.CI086-K97(Z.E9%
M4E-)3TX`,2XP-C,`+64`+2T`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B
M9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z('!R:79A=&4@
M<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A
M;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``56YA8FQE('1O(&-R96%T92!C
M86-H92!D:7)E8W1O<GD`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C
M:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@````!E=F%L
M("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@
M(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?
M<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O9F9S971?<VEZ92P@)&-A8VAE
M7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN
M(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I"B1C86-H
M95]N86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!1TE#(#T@(E!+7#`P,UPP,#0B
M.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY("@D9F@I(#T@0%\["FUY("1C
M:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US
M("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M("@D<VEZ92TQ*2`E("1C:'5N
M:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I<R!A(&UU;'1I<&QE(&]F("1C
M:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I('L*<V5E:R`D9F@L("1P;W,L
M(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%2
M7TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#
M*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K("1I.PI]"B1P;W,@+3T@)&-H=6YK
M7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M
M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D14Y6>U!!
M4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z
M.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&
M:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q6U)E
M;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I;F0Z.F9I
M;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R
M7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@
M)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H
M"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M
M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+
M(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE.PIP<FEN
M="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O
M"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[
M('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*
M<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W,#`L("1F
M:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L;"`R/B8Q
M("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K9W)O=6YD
M('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=*3L*?0I]
M('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@
M)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I
M.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@*`IP
M871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*
M7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI
M+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU3
M5VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO
M=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T
M96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%
M35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T87)T7V]F7T9)3$5?<V5C=&EO
M;BD["DU!1TE#.B!["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIU
M;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64I('L*;W5T<RAQ
M<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@(R!D;VXG
M="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL87-T($U!
M1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@J7T9(*3L*
M:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN9"!M86=I
M8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*
M;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!005(@;6%G:6,@870@<&]S:71I
M;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%
M7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!0TA%(BDL(#`["G)E860@7T9(
M+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@;F4@(EPP0T%#
M2$4B("8F("1B=68@;F4@(EPP0TQ%04XB*2!["F]U=',H(DYO(&-A8VAE(&UA
M<FME<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]"F]U=',H<7%;0V%C:&4@;6%R
M:V5R("(D8G5F(B!F;W5N9%TI.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&
M24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@)&)U9BP@)$9)3$5?;V9F
M<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A8VLH(DXB+"`D8G5F*3L*;W5T
M<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@:7,@)&]F9G-E="(I.PIS
M965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@)&]F
M9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C=&EO;B`]('1E;&P@7T9(.PIM
M>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@
M("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL
M92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@
M7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@
M)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI
M.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\
M("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F
M(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T
M.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I
M;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@
M>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P
M-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I
M;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D
M9G5L;&YA;64["GT*96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA;65](#T@
M>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE
M+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D(%]&2"P@
M)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO
M9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE
M.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T=7)N('5N
M;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T["B1)
M3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%
M3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@
M8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP
M<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E='5R;B`D
M9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D:6YF;RT^
M>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5](#T@)&9I
M;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I
M92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@[
M"GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U
M;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q
M=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E
M($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@
M*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[
M)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F
M:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]
M"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET
M96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F
M:6QE;F%M97T["GT*:68@*"1B=68@;F4@)%!+6DE07TU!1TE#*2!["F]U=',H
M<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F:6QE("(D
M<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@/2`H=&5L
M;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM
M>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H
M95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I
M>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"FEF("@A)'-T
M87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H
M:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@
M("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*
M=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G
M+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@
M/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO
M=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]
M?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@
M97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E
M<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2![
M"G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2![
M"B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G
M<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<[
M"GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D
M,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q<5M#
M86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@97$@
M)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H
M;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]4
M14U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z
M.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@
M0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I
M;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!
M.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I
M;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@9&EE
M('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L97-S*"1F
M:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D
M>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@
M87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A7W!A<B`](&1O('L*:68@*"1Z
M:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI
M('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO
M+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@
M*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O
M<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@
M)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T
M(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q("102UI)4%]-04=)0SL*8VQO
M<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z
M.D]?4D174B@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D
M:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN
M;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@*&1E9FEN
M960@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD@>PIR96%D(%]&2"P@)&QO861E
M<BP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;CL*?2!E;'-E('L*;&]C86P@)"\@
M/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?5D52
M0D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"B1F:"T^<')I;G0H)&QO861E
M<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R('1O("(D;W5T(CH@
M)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER
M95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E
M<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O
M;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R
M:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A8V@@
M0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R
M.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT
M(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@6%A8(&QI
M8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D:V5Y
M("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I.PII9B`H
M9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K97E]
M*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@>PIF
M;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D9&ER
M7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D,2D["FQA
M<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI('L*
M:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA
M;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B*2![
M"B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*
M?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@)'=R:71T
M96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^
M("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI;F<@
M1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F
M:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N
M="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*
M;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG="!R
M96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO<V4@)'1H
M.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE
M;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D
M;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C
M:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I
M.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N86UE
M*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP
M=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG=&@H
M)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG
M(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D(5T["F]U=',H<7%;5W)I='1E
M;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II<"D@>PHD>FEP+3YW<FET951O
M1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*;W(@9&EE
M('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@;V8@(B1O=70B73L*?0II9B`H
M)&UE=&%?<&%R>V-L96%N?2D@>PHD9F@M/G!R:6YT*")<,$-,14%.(BD["GT*
M96QS92!["FEF("@A9&5F:6YE9"`D8V%C:&5?;F%M92D@>PIM>2`D8W1X(#T@
M1&EG97-T.CI32$$M/FYE=R@Q*3L*<V5E:R`D9F@L(#`L(#`["B1C='@M/F%D
M9&9I;&4H)&9H*3L*<V5E:R`D9F@L(#`L(#(["B1C86-H95]N86UE(#T@)&-T
M>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N
M86UE+"`P+"`D8V%C:&5?;F%M95]S:7IE.PHD8V%C:&5?;F%M92`N/2`B7#`B
M('@@*"1C86-H95]N86UE7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD
M9F@M/G!R:6YT*"1C86-H95]N86UE+`HB7#!#04-(12(I.PI]"FUY("1O9F9S
M970@/2`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BD["B1F:"T^<')I;G0H
M<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!1TE#*3L*)&9H+3YC;&]S92!O
M<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T(CH@)"%=
M.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F
M:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2
M.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&
M:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!
M<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D
M;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N*"D@9F%I
M;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D[
M"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E861&<F]M
M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B
M)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@
M,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A
M8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S*")%>'1R86-T:6YG('II<"XN
M+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B
M92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II
M<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*
M;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL
M97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z
M.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C
M=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F
M:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D
M97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE
M*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I
M="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*
M;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N
M86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T
M7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R
M<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M92)=.PIC
M:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*
M?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@
M/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@
M6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN
M<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[
M4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I
M.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@
M/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D[
M"G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H
M*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*
M?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@
M1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*
M<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`[
M"G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@
M17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C
M;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*
M<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z
M.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ
M6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI3
M2$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@
M4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q
M=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I
M8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7
M:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![
M(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U
M:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E
M(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q
M=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO
M*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T
M:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U0
M1$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE
M>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D
M<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I
M(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D
M*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,
M;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M
M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-
M17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M<&1I<B`]
M("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA
M;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I<CL*:68@
M*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PI]
M"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I
M92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["FEF("@H;7D@)&UA
M9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*<V5E:R`D
M9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B
M7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@;&5N9W1H
M*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F
M:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<
M,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P.PIR96%D("1F:"P@)&)U
M9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S+UPP+R]G.PHD8V%C:&5?
M9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@)&9H.PI]"FEF("@A)&-A
M8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PHD14Y6>U!!4E]#
M3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES>U]D96QI;7TD8V%C:&5?
M9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%3E9[4$%27U1%35!](#T@
M)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?
M5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W-A
M=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY
M("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F
M=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;7D@
M)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@*'!R:6YT
M("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q<5M%<G)O
M<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E+"`D=&5M
M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U
M;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN
M86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM0
M05)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO
M*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D
M14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]4
M14U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R
M:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*:68@*"$D
M14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D<WES>U]D
M96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M
M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)'-Y
M<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E='5R;CL*
M?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H7W-E<'U<
M12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-
M4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421S
M>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L
M:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1S
M>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G;F%M92`]
M("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D
M9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N
M86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*
M:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I('L*)'!R
M;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@
M/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H
M9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@
M<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<
M421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.5GM005)?
M4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*
M:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX[
M"GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ
M=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@
M*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!435!$25(@
M5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@)$5.5GLB
M4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/0D%,7R1?
M(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#
M3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D
M;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@
M(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U
M<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1?
M?2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E
M;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G
M92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN
M9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ
M($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@
M9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@
M)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E4
M7UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D
M0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>
M7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?
M15)23U(["C$["E]?14Y$7U\*``!#04-(10``<&5R;'AS:2YC`````1L#.S`!
M```E````1(S__T0"```4D/__:`(``$20__],`0``?Y#__W`!``"(D?__H`$`
M`.61___@`0``5)3__WP"```*E?__U`(``(J5__\4`P``^Y;__U0#```+F?__
ME`,``)B9___,`P``EYK___P#```[F___-`0``(F;__]8!```\IO__X`$``#U
MF___E`0```J>___4!```0Y[__P`%``"6GO__/`4``,^?__]T!0``)*#__Z0%
M``!BH/__P`4``#*B___P!0``7:+__Q0&```<H___5`8``/>I__^8!@``3:S_
M_\@&``"TK/__3`<``*.X__^0!P``^KC__[0'```PN___#`@``"Z]__\<!P``
M;;___P@"``!QO___'`(``'6___\P`@``>;___TP(```4``````````%Z4@`!
M?`@!&PP$!(@!```@````'````/".__\[`````$$."(8"00X,@P-WPPX(0<8.
M!``L````0`````>/__\)`0```$$."(<"00X,A@-!#A"#!`+5"L,.#$'&#@A!
MQPX$00L\````<````."/__]=`````$$."(4"00X,AP-!#A"&!$$.%(,%0PX8
M`DD*#A1!PPX00<8.#$''#@A!Q0X$00L`)````+````#]C___A`$```!!#@B%
M`D$.#(<#00X0A@1!#A2#!4,.+!````#8````7;W__P0`````````$````.P`
M``!-O?__!``````````0``````$``#V]__\$`````````"`````4`0``^(G_
M_]`#````#@A&#@Q*#PMT!'@`/QH[*C(D(A`````X`0``I(W__R``````````
M5````$P!``#0D?__M@````!!#@B%`D$.#(<#00X0A@1!#A2#!4,.+`)T"@X4
M0<,.$$'&#@Q!QPX(0<4.!$$+;0H.%$'##A!!Q@X,0<<."$'%#@1!"P```#P`
M``"D`0``+I+__X``````00X(A0)!#@R'`T$.$(8$00X4@P5##B`";PH.%$'#
M#A!!Q@X,0<<."$'%#@1!"P`\````Y`$``&Z2__]Q`0```$$."(4"00X,AP-!
M#A"&!$$.%(,%1@ZX`7X*#A1!PPX00<8.#$''#@A!Q0X$00L`/````"0"``"?
MD___$`(```!!#@B%`D$.#(<#00X0A@1!#A2#!4,./`,5`0H.%$'##A!!Q@X,
M0<<."$'%#@1!"S0```!D`@``;Y7__XT`````00X(AP)!#@R&`T$.$(,$1@Z8
M`0)="@X00<,.#$'&#@A!QPX$00L`+````)P"``#$E?___P````!!#@B%`D(-
M!4R'`X8$@P4"N0K#0<9!QT'%#`0$00L`-````,P"``"3EO__I`````!!#@B'
M`D$.#(8#00X0@P1&#J`(`GT*#A!!PPX,0<8."$''#@1!"P`@````!`,``/^6
M__].`````$$."(4"0@T%1X,#`D/%PPP$!``D````*`,``"F7__]I`````$$.
M"(4"0@T%2(8#@P0"6\-!QD'%#`0$$````%`#``!JE___`P`````````\````
M9`,``%F7__\5`@```$$."(4"00X,AP-!#A"&!$$.%(,%1@[$"0)["@X40<,.
M$$'&#@Q!QPX(0<4.!$$+*````*0#```NF?__.0````!!#@B&`D$.#(,#0PX4
M<0X,0<,."$'&#@0````X````T`,``#N9__]3`````$$."(8"00X,@P-##A!O
M"@X,0<,."$'&#@1%"U$*#@Q!PPX(0<8.!$$+```T````#`0``%*9__\Y`0``
M`$$."(<"00X,A@-!#A"#!$,.&`,*`0H.$$'##@Q!Q@X(0<<.!$$+`"P```!$
M!```4YK__U4`````00X(A@)!#@R#`T,.%`)("@X,0<,."$'&#@1!"P```!@`
M``!T!```>)K__SX`````00X(@P)##A0````L````D`0``)J:___0`0```$$.
M"(4"0@T%28<#A@2#!0-D`0K#0<9!QT'%#`0$00L@````P`0``#J<__\K````
M`$$."(,"0PX,80H."$'##@1!"P`\````Y`0``$&<__^_`````$$."(4"00X,
MAP-!#A"&!$$.%(,%0PXT`D\*#A1!PPX00<8.#$''#@A!Q0X$00L`0````"0%
M``#`G/__VP8```!!#@B%`D$.#(<#00X0A@1!#A2#!48.L`(#^P(*#A1!PPX0
M0<8.#$''#@A!Q0X$00L````L````:`4``%>C__]6`@```$$."(4"0@T%28<#
MA@2#!0.Z`0K#0<9!QT'%#`0$00M0````F`4``'VE__]G`````$$."(4"00X,
MAP-!#A"&!$$.%(,%0PX890H.%$'##A!!Q@X,0<<."$'%#@1!"VT.%$'##A!!
MQ@X,0<<."$'%#@0````L````[`4```JV__\_`@```$$."(4"0@T%28<#A@2#
M!0.#`0K#0<9!QT'%#`0$00M`````'`8``&"E___O"P```$$."(4"00X,AP-!
M#A"&!$$.%(,%1@[X`@/7"PH.%$'##A!!Q@X,0<<."$'%#@1!"P```"````!@
M!@``"['__U<`````00X(@P)##@P"40X(0<,.!````%0```"$!@``/K'__S8"
M````00X(A0)!#@R'`T$.$(8$00X4@P5##AP"D@H.%$'##A!!Q@X,0<<."$'%
M#@1!"P++"@X40<,.$$'&#@Q!QPX(0<4.!$$+```\````W`8``!RS___^`0``
M`$$."(4"00X,AP-!#A"&!$$.%(,%0PXD`VD!"@X40<,.$$'&#@Q!QPX(0<4.
M!$$+$````!P'```EM___!```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````/____\`````_____P``````
M`````0````$````!````H@(```$```#:`@```0```.@"```!````#@,```\`
M``"%!```#````"`2```-````<$4```0```!X`0``!0```.@*```&````F`0`
M``H```#*!```"P```!`````5``````````,`````H````@```.`!```4````
M$0```!<````T$```$0```+0/```2````@````!,````(````^___;P````CZ
M__]O!```````````````````````````````````````````````````````
M``````````````````````````````````````````````````#LG@``````
M````````````[)X`````````````1A(``%82``!F$@``=A(``(82``"6$@``
MIA(``+82``#&$@``UA(``.82``#V$@``!A,``!83```F$P``-A,``$83``!6
M$P``9A,``'83``"&$P``EA,``*83``"V$P``QA,``-83``#F$P``]A,```84
M```6%```)A0``#84``!&%```5A0``&84``!V%```AA0``)84``"F%```MA0`
M`,84``#6%```YA0``/84```&%0``%A4``"85```V%0``1A4``%85``!F%0``
M=A4``(85``"6%0``IA4``+85``#&%0``UA4``.85``#V%0``1*$```"A````
M```````````````````````````````````````````````*4$%2+G!M"@``
M``!H2```1T-#.B`H3F5T0E-$(&YB-"`R,#(P,#@Q,"D@-RXU+C``1T-#.B`H
M;F(T(#(P,C`P.#$P*2`W+C4N,``D3F5T0E-$.B!C<G0P+E,L=B`Q+C0@,C`Q
M."\Q,2\R-B`Q-SHS-SHT-2!J;V5R9R!%>'`@)``D3F5T0E-$.B!C<G0P+6-O
M;6UO;BYC+'8@,2XR,R`R,#$X+S$R+S(X(#(P.C$R.C,U(&-H<FES=&]S($5X
M<"`D`"1.971"4T0Z(&-R=&DN4RQV(#$N,2`R,#$P+S`X+S`W(#$X.C`Q.C,S
M(&IO97)G($5X<"`D`"1.971"4T0Z(&-R=&)E9VEN+E,L=B`Q+C$@,C`Q,"\P
M."\P-R`Q.#HP,3HS,R!J;V5R9R!%>'`@)``D3F5T0E-$.B!C<G1E;F0N4RQV
M(#$N,2`R,#$P+S`X+S`W(#$X.C`Q.C,S(&IO97)G($5X<"`D`"1.971"4T0Z
M(&-R=&XN4RQV(#$N,2`R,#$P+S`X+S`W(#$X.C`Q.C,T(&IO97)G($5X<"`D
M`/'/`@`````````````````(````"`````@````(````&P````$`````````
M`"HJ*B!.;R!,86)E;"!0<F]V:61E9"`J*BH``/'/`@`````````````````(
M````"`````@````(````&P````$``````````"HJ*B!.;R!,86)E;"!0<F]V
M:61E9"`J*BH``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+FYE=&)S9"YI9&5N
M=``N;F]T92YN971B<V0N<&%X`"YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N<F5L
M+F1Y;@`N<F5L+G!L=``N:6YI=``N<&QT+F=O=``N=&5X=``N9FEN:0`N<F]D
M871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YC=&]R<P`N9'1O<G,`+FIC
M<@`N9'EN86UI8P`N9V]T+G!L=``N9&%T80`N8G-S`"YC;VUM96YT`"Y354Y7
M7V-T9@``````````````````````````````````````````````````````
M"P````$````"````-`$``#0!```7```````````````!`````````!,````'
M`````@```$P!``!,`0``&```````````````!``````````F````!P````(`
M``!D`0``9`$``!0```````````````0`````````-P````4````"````>`$`
M`'@!```@`P``!0`````````$````!````#T````+`````@```)@$``"8!```
M4`8```8````!````!````!````!%`````P````(```#H"@``Z`H``,H$````
M``````````$`````````30````D````"````M`\``+0/``"`````!0``````
M```$````"````%8````)````0@```#00```T$```X`$```4````6````!```
M``@```!?`````0````8````@$@``(!(```H``````````````!``````````
M6@````$````&````,!(``#`2``#0`P`````````````0````!````&4````!
M````!@`````6````%@``(```````````````"`````@```!N`````0````8`
M```@%@``(!8``$DO`````````````!``````````=`````$````&````<$4`
M`'!%```*```````````````0`````````'H````!`````@```'Q%``!\10``
M;D``````````````!`````````""`````0````(```#LA0``[(4``#0!````
M``````````0`````````D`````$````"````((<``""'```P!P``````````
M```$`````````)H````!`````P```-B>``#8C@``"```````````````!```
M``````"A`````0````,```#@G@``X(X```@```````````````0`````````
MJ`````$````#````Z)X``.B.```$```````````````$`````````*T````&
M`````P```.R>``#LC@``X`````8`````````!`````@```!I`````0````,`
M``#,GP``S(\``#0```````````````0````$````M@````$````#`````*``
M``"0``#\```````````````$````!````+\````!`````P```/R@``#\D```
M/```````````````!`````````#%````"`````,```!`H0``.)$``$0`````
M`````````$``````````R@````$````P`````````#B1```[````````````
M```!`````0```!\````!``````````````!SD0``50$``````````````0``
M``````#3`````0``````````````R)(``(\```````````````0`````````
H`0````,``````````````%>3``#=```````````````!````````````
